/*

    xpuyopuyo - pgraph-gtk.h     Copyright(c) 1999-2003 Justin David Smith
    justins(at)chaos2.org        http://chaos2.org/


    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/


#ifndef __pgraph_gtk_h_included
#define __pgraph_gtk_h_included


#include <xpuyopuyo.h>
#if !USE_LISP_AI


#include <pwindow-gtk.h>


void p_graph_ai(pwindow_gtk *w);


#endif /* !USE_LISP_AI */


#endif

